xudo-cli
========

*A command line program to replace dockdock, written in Python3*

Installation
------------

``pip install xudo``

``touch ~/.xudo_profile``

Copy the absolute path of where the api folder is stored eg.

/Users/ostralyan/api

Usage
-----

``xudo logs [api | changelog | migrations | rcash]`` - This will follow the logs of the chosen container

``xudo pull``

``xudo build [-c -m -s -e -r -a -x]``

``xudo clean``

``xudo -h | --help``

``xudo --version``
